@@ -1,45 +1,52 @@
 /***********************************************************************************
 
- Copyright (C) 2007-2012 Ahmet Öztürk (aoz_2@yahoo.com)
+    Copyright (C) 2007-2012 Ahmet Öztürk (aoz_2@yahoo.com)
 
- This file is part of Lifeograph.
+    This file is part of Lifeograph.
 
- Lifeograph is free software: you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation, either version 3 of the License, or
- (at your option) any later version.
+    Lifeograph is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
 
- Lifeograph is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
+    Lifeograph is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
 
- You should have received a copy of the GNU General Public License
- along with Lifeograph.  If not, see <http://www.gnu.org/licenses/>.
+    You should have received a copy of the GNU General Public License
+    along with Lifeograph.  If not, see <http://www.gnu.org/licenses/>.
 
- ***********************************************************************************/
+***********************************************************************************/
 
 #include <gtkmm/table.h>
 
-#include "lifeobase.hpp"
+#include "lifeograph.hpp"
 #include "dialog_export.hpp"
 #include "dialog_password.hpp"
 
 using namespace LIFEO;
 
-// DIALOGSAVEDIARY =================================================================================
-DialogSaveDiary::DialogSaveDiary( void )
-: Gtk::FileChooserDialog(
-        // TRANSLATORS: this is the title of file chooser dialog for saving a new diary
-        _( "Where to Save The Diary?" ), Gtk::FILE_CHOOSER_ACTION_SAVE )
+// DIALOG SAVE GENERIC =============================================================================
+DialogSaveGeneric::DialogSaveGeneric( const Glib::ustring &title )
+:   Gtk::FileChooserDialog( title, Gtk::FILE_CHOOSER_ACTION_SAVE )
 {
     add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
-    add_button( Gtk::Stock::OK, Gtk::RESPONSE_ACCEPT );
+    add_button( Gtk::Stock::SAVE, Gtk::RESPONSE_ACCEPT );
+    set_do_overwrite_confirmation( true );
+}
+
+DialogSaveGeneric::DialogSaveGeneric( BaseObjectType* cobject,
+                                      const Glib::RefPtr< Gtk::Builder > &refbuilder )
+:   Gtk::FileChooserDialog( cobject )
+{
+    add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
+    add_button( Gtk::Stock::SAVE, Gtk::RESPONSE_ACCEPT );
     set_do_overwrite_confirmation( true );
 }
 
 std::string
-DialogSaveDiary::get_filename( const std::string &extension )
+DialogSaveGeneric::get_filename( const std::string &extension )
 {
     std::string fname( FileChooserDialog::get_filename() );
 
@@ -50,13 +57,80 @@ DialogSaveDiary::get_filename( const std::string &extension )
     return fname;
 }
 
-std::string
-DialogSaveDiary::get_filename_default( void ) // appends default diary extension
+// DIALOG SAVE DIARY ===============================================================================
+DialogSaveDiary *DialogSaveDiary::ptr = NULL;
+
+DialogSaveDiary::DialogSaveDiary( BaseObjectType* cobject,
+                                  const Glib::RefPtr< Gtk::Builder > &refbuilder )
+:   DialogSaveGeneric( cobject, refbuilder )
 {
-    return get_filename( Lifeobase::settings.diary_extension );
+    try
+    {
+        Lifeograph::builder->get_widget( "check_save_encrypt", m_check_encrypt );
+        Lifeograph::builder->get_widget( "grid_save_password", m_grid_password );
+        Lifeograph::builder->get_widget( "entry_save_password", m_entry_password );
+        Lifeograph::builder->get_widget( "entry_save_confirm", m_entry_confirm );
+    }
+    catch( ... )
+    {
+        throw LIFEO::Error( "creation of save dialog failed" );
+    }
+
+    m_check_encrypt->signal_toggled().connect(
+            sigc::mem_fun( this, &DialogSaveDiary::handle_encryption_toggled ) );
+    m_entry_password->signal_changed().connect(
+            sigc::mem_fun( this, &DialogSaveDiary::handle_password_changed ) );
+    m_entry_confirm->signal_changed().connect(
+            sigc::mem_fun( this, &DialogSaveDiary::handle_password_changed ) );
 }
 
-// DIALOGOPENDIARY =================================================================================
+int
+DialogSaveDiary::launch( std::string &path, std::string &passphrase )
+{
+    if( ptr  == NULL )
+        Lifeograph::builder->get_widget_derived( "filedialog_save", ptr );
+
+    ptr->set_current_folder( Glib::path_get_dirname( path ) );
+    ptr->set_current_name( Glib::path_get_basename( path ) );
+    ptr->m_check_encrypt->set_active( false );
+
+    int ret_value( ptr->run() );
+    path = ptr->get_filename( Lifeograph::settings.diary_extension );
+    passphrase = ptr->m_entry_password->get_text();
+    ptr->hide();
+    ptr->set_current_folder( "/" ); // this prevents gtkrbtree core dumps, details not known
+
+    return ret_value;
+}
+
+void
+DialogSaveDiary::handle_encryption_toggled( void )
+{
+    bool active( m_check_encrypt->get_active() );
+    m_grid_password->set_visible( active );
+    if( !active )
+    {
+        m_entry_password->set_text( "" );
+        m_entry_confirm->set_text( "" );
+    }
+    else
+    {
+        m_entry_password->grab_focus();
+    }
+    set_response_sensitive( Gtk::RESPONSE_ACCEPT, !active );
+}
+
+void
+DialogSaveDiary::handle_password_changed( void )
+{
+    Glib::ustring passphrase( m_entry_password->get_text() );
+    bool pass_ok( passphrase.size() >= LIFEO::PASSPHRASE_MIN_SIZE &&
+                  passphrase == m_entry_confirm->get_text() );
+
+    set_response_sensitive( Gtk::RESPONSE_ACCEPT, pass_ok );
+}
+
+// DIALOG OPEN DIARY ===============================================================================
 bool DialogOpenDiary::flag_filters_created = false;
 Glib::RefPtr< Gtk::FileFilter > DialogOpenDiary::filter_any;
 Glib::RefPtr< Gtk::FileFilter > DialogOpenDiary::filter_diary;
@@ -113,20 +187,20 @@ DialogImport::DialogImport( BaseObjectType* cobject,
                             const Glib::RefPtr< Gtk::Builder > &refbuilder )
 :   DialogEvent( cobject, refbuilder ), m_dialog_password( NULL ), m_diary( NULL )
 {
-    Lifeobase::builder->get_widget( "filebutton_import_diary",
+    Lifeograph::builder->get_widget( "filebutton_import_diary",
             m_file_chooser_button );
-    Lifeobase::builder->get_widget( "label_import_info", m_label_info );
-    Lifeobase::builder->get_widget( "label_import_entries", m_label_entries );
-    Lifeobase::builder->get_widget( "label_import_tags", m_label_tags );
-    Lifeobase::builder->get_widget( "label_import_themes", m_label_themes );
-    Lifeobase::builder->get_widget_derived( "entry_import_add_tag",
+    Lifeograph::builder->get_widget( "label_import_info", m_label_info );
+    Lifeograph::builder->get_widget( "label_import_entries", m_label_entries );
+    Lifeograph::builder->get_widget( "label_import_tags", m_label_tags );
+    Lifeograph::builder->get_widget( "label_import_themes", m_label_themes );
+    Lifeograph::builder->get_widget_derived( "entry_import_add_tag",
             m_tag_widget );
 
-    Lifeobase::builder->get_widget( "checkbutton_import_entries",
+    Lifeograph::builder->get_widget( "checkbutton_import_entries",
             m_checkbutton_import_entries );
-    Lifeobase::builder->get_widget( "checkbutton_import_tags",
+    Lifeograph::builder->get_widget( "checkbutton_import_tags",
             m_checkbutton_import_tags );
-    Lifeobase::builder->get_widget( "checkbutton_import_themes",
+    Lifeograph::builder->get_widget( "checkbutton_import_themes",
             m_checkbutton_import_themes );
 
     // FILTERING
@@ -159,6 +233,9 @@ DialogImport::on_show( void )
     Gtk::Dialog::on_show();
     set_not_ready( _( "Select a diary file for importing" ) );
 
+    m_file_chooser_button->unselect_all();
+    m_tag_widget->set_text( "" );
+
     m_checkbutton_import_entries->set_active( true );
     m_checkbutton_import_tags->set_active( true );
     m_checkbutton_import_themes->set_active( true );
@@ -182,15 +259,8 @@ DialogImport::handle_diary_changed( void )
     {
         if( m_diary->is_encrypted() )
         {
-            if( m_dialog_password == NULL )
-                Lifeobase::builder->get_widget_derived(
-                        "dialog_import_password", m_dialog_password );
-            m_dialog_password->set_transient_for( *this );
-            m_dialog_password->set_path( m_diary->get_name() );
-            if( m_dialog_password->run() == RESPONSE_GO )
-                m_diary->set_passphrase(
-                        m_dialog_password->m_entry->get_text() );
-            m_dialog_password->hide();
+            DialogPassword::launch( DialogPassword::OT_OPEN, m_diary );
+            // TODO: do something if result != RESPONSE_GO
         }
 
         Result result = m_diary->read_body();
@@ -280,7 +350,7 @@ DialogImport::on_response( int response )
 
         if( m_option_import_entries )
         {
-            Diary::d->import_entryset( m_diary->m_entries, m_option_import_tags,
+            Diary::d->import_entries( *m_diary, m_option_import_tags,
                     m_tag_widget->get_text() );
         }
     }
@@ -291,16 +361,16 @@ DialogImport::on_response( int response )
     Gtk::Dialog::on_response( response );
 }
 
-// DIALOGEXPORT ====================================================================================
+// DIALOG EXPORT ===================================================================================
 DialogExport::DialogExport( BaseObjectType* cobject,
         const Glib::RefPtr< Gtk::Builder > &refbuilder )
 :   DialogEvent( cobject, refbuilder ), m_ptr2widget_options( NULL ), m_ptr2diary( Diary::d )
 {
-    Lifeobase::builder->get_widget( "combo_export_type", m_combo_type );
-    Lifeobase::builder->get_widget( "combo_export_extent", m_combo_extent );
-    Lifeobase::builder->get_widget( "frame_export_options", m_frame_options );
-    Lifeobase::builder->get_widget( "align_export_options", m_align_options );
-    Lifeobase::builder->get_widget( "button_export_go", m_button_export );
+    Lifeograph::builder->get_widget( "combo_export_type", m_combo_type );
+    Lifeograph::builder->get_widget( "combo_export_extent", m_combo_extent );
+    Lifeograph::builder->get_widget( "frame_export_options", m_frame_options );
+    Lifeograph::builder->get_widget( "align_export_options", m_align_options );
+    Lifeograph::builder->get_widget( "button_export_go", m_button_export );
 
     add_saver( new ExporterLifeograph( m_ptr2diary ) );
     add_saver( new ExporterText( m_ptr2diary ) );
@@ -313,8 +383,6 @@ DialogExport::DialogExport( BaseObjectType* cobject,
             sigc::mem_fun( this, &DialogExport::handle_savetype_changed ) );
 
     m_combo_type->set_active( 0 );    // defaults to lifeograph diary
-
-    show_all();
 }
 
 void
@@ -364,14 +432,8 @@ DialogExport::on_response( int response )
 {
     if( response == RESPONSE_GO )
     {
-        DialogSaveDiary *ds( new DialogSaveDiary );
-        ds->set_current_folder( Glib::path_get_dirname( m_ptr2diary->get_path() ) );
-        ds->set_current_name( m_ptr2diary->get_name() + ".backup" );
-
-        if( ds->run() == Gtk::RESPONSE_ACCEPT )
-            m_saver_cur->save( ds->get_filename(), m_combo_extent->get_active() );
-
-        delete ds;
+        // TODO: handle result
+        m_saver_cur->save( m_combo_extent->get_active() );
     }
 
     Gtk::Dialog::on_response( response );
@@ -384,15 +446,15 @@ Diarysaver::Diarysaver( const Glib::ustring& name, Diary *diary )
 }
 
 ExporterLifeograph::ExporterLifeograph( Diary *diary )
-:   Diarysaver( _( "Lifeograph Diary File" ), diary ), m_passphrase( "" ),
-    m_flag_encrypted( false )
+:   Diarysaver( _( "Lifeograph Diary File" ), diary ) //, m_passphrase( "" ),
+    //m_flag_encrypted( false )
 {
 }
 
 Gtk::Widget*
 ExporterLifeograph::draw_options( void )
 {
-    m_entry_passphrase = Gtk::manage( new Gtk::Entry );
+    /*m_entry_passphrase = Gtk::manage( new Gtk::Entry );
     m_entry_confirm = Gtk::manage( new Gtk::Entry );
     m_check_encrypt = Gtk::manage( new Gtk::CheckButton( _( "Encrypt Diary Content" ) ) );
     Gtk::Table *table = new Gtk::Table;
@@ -424,16 +486,18 @@ ExporterLifeograph::draw_options( void )
 
     table->show_all();
 
-    return table;
+    return table;*/
+    return NULL;
 }
 
 bool
 ExporterLifeograph::is_ready( void )
 {
-    return( ( ! m_flag_encrypted ) || m_passphrase.size() >= LIFEO::PASSPHRASE_MIN_SIZE );
+    //return( ( ! m_flag_encrypted ) || m_passphrase.size() >= LIFEO::PASSPHRASE_MIN_SIZE );
+    return true;
 }
 
-void
+/*void
 ExporterLifeograph::handle_passphrase_changed( void )
 {
     m_passphrase = m_entry_passphrase->get_text();
@@ -455,13 +519,19 @@ ExporterLifeograph::handle_encryption_changed( void )
 
     m_signal_updated.emit( ( ! m_flag_encrypted ) ||
                            m_passphrase.size() >= LIFEO::PASSPHRASE_MIN_SIZE );
-}
+}*/
 
 Result
-ExporterLifeograph::save( const std::string &path, bool filtered )
+ExporterLifeograph::save( bool filtered )
 {
-    if( m_flag_encrypted && m_passphrase.size() >= LIFEO::PASSPHRASE_MIN_SIZE )
-        return m_ptr2diary->write_copy( path, m_passphrase, filtered );
+    std::string path( m_ptr2diary->get_path() + ".backup" );
+    std::string pass;
+
+    if( DialogSaveDiary::launch( path, pass ) != Gtk::RESPONSE_ACCEPT )
+        return LIFEO::ABORTED;
+
+    if( pass.size() >= LIFEO::PASSPHRASE_MIN_SIZE )
+        return m_ptr2diary->write_copy( path, pass, filtered );
     else
         return m_ptr2diary->write_copy( path, "", filtered );
 }
@@ -473,7 +543,19 @@ ExporterText::ExporterText( Diary *diary )
 }
 
 Result
-ExporterText::save( const std::string &path, bool filtered )
+ExporterText::save( bool filtered )
 {
+    // TRANSLATORS: this is the title of file chooser dialog for saving a new diary
+    DialogSaveGeneric *ds( new DialogSaveGeneric( _( "Where to Save the Text File?" ) ) );
+    ds->set_current_folder( Glib::path_get_dirname( m_ptr2diary->get_path() ) );
+    ds->set_current_name( Glib::path_get_basename( m_ptr2diary->get_path() ) + ".txt" );
+    if( ds->run() != Gtk::RESPONSE_ACCEPT )
+    {
+        delete ds;  // also removes the dialog from the screen
+        return LIFEO::ABORTED;
+    }
+
+    std::string path( ds->get_filename() );
+    delete ds;
     return m_ptr2diary->write_txt( path, filtered );
 }
