@@ -33,68 +33,55 @@
 namespace LIFEO
 {
 
-// PASSWORD ADD/CHANGE DIALOG ======================================================================
+// PASSWORD DIALOG =================================================================================
 class DialogPassword : public DialogEvent
-{
-	public:
-							DialogPassword(	const std::string&, const Glib::ustring& );
-
-        void				on_response( int );
-		
-        void				authenticate( void );
-        void				check_match( void );
-
-		bool				is_passphrase_set( void ) const
-		{
-			return m_passphrase_is_set;
-		}
-
-		std::string			get_passphrase( void ) const
-		{
-			return m_passphrase_new;
-		}
-
-	protected:
-        Gtk::Button         *m_button_authenticate;
-		Gtk::Button         *m_button_change;
-		Gtk::Entry	        *m_entry_current;
-		Gtk::Entry	        *m_entry_confirm;
-		Gtk::Entry	        *m_entry_new;
-        Gtk::Image          *m_image_match;
-
-		const std::string	m_passphrase_old;
-		std::string			m_passphrase_new;
-		bool				m_passphrase_is_set;
-
-	private:
-
-};
-
-// PASSWORD PROMPT DIALOG ==========================================================================
-class DialogPasswordPrompt : public DialogEvent
 {
     public:
-                                    DialogPasswordPrompt(
+        enum OperationType
+        // Build blocks: cur=1, new=2, check=4, set=8
+        {
+            // blocks:
+            OT_CHECK=1,
+            OT_SET=2,
+            OT_CURRENT=4,
+            OT_NEW=8,
+            // composites:
+            OT_AUTHENTICATE = 5,
+            OT_OPEN = 6,
+            OT_ADD = 10,
+            OT_CHANGE = 15,
+        };
+
+                                    DialogPassword(
                                             BaseObjectType*,
                                             const Glib::RefPtr< Gtk::Builder >& );
 
-        int                         run( void );
-        int                         run_again( void );
-
-        void                        set_message( const Glib::ustring& );
-        void                        set_path( const Glib::ustring& );
-        Glib::ustring               get_password( void ) const
-        { return m_entry->get_text(); }
+        static int                  launch( OperationType, Diary*, bool = false );
 
     protected:
-        void                        on_hide( void );
         void                        handle_entry_changed( void );
+        void                        authenticate( void );
+        void                        check_match( void );
 
-        EntryClear                  *m_entry;
+        Gtk::Button                 *m_button_go;
+        EntryClear                  *m_entry_current;
         Gtk::Label                  *m_label_msg;
         Gtk::Label                  *m_label_path;
 
-    friend class DialogImport;
+        Gtk::Grid                   *m_grid_new;
+        Gtk::Grid                   *m_grid_authenticate;
+        Gtk::Button                 *m_button_authenticate;
+        EntryClear                  *m_entry_new;
+        EntryClear                  *m_entry_confirm;
+        Gtk::Image                  *m_image_new;
+        Gtk::Image                  *m_image_confirm;
+
+        Diary                       *m_ptr2diary;
+        OperationType               m_ot;
+
+        static DialogPassword       *ptr;
+
+        static const int            SLEEP_DURATION = 2;
 };
 
 } // end of namespace LIFEO
