@@ -1,21 +1,21 @@
 /***********************************************************************************
 
-	Copyright (C) 2007-2012 Ahmet Öztürk (aoz_2@yahoo.com)
+    Copyright (C) 2007-2012 Ahmet Öztürk (aoz_2@yahoo.com)
 
-	This file is part of Lifeograph.
+    This file is part of Lifeograph.
 
-	Lifeograph is free software: you can redistribute it and/or modify
-	it under the terms of the GNU General Public License as published by
-	the Free Software Foundation, either version 3 of the License, or
-	(at your option) any later version.
+    Lifeograph is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
 
-	Lifeograph is distributed in the hope that it will be useful,
-	but WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-	GNU General Public License for more details.
+    Lifeograph is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
 
-	You should have received a copy of the GNU General Public License
-	along with Lifeograph.  If not, see <http://www.gnu.org/licenses/>.
+    You should have received a copy of the GNU General Public License
+    along with Lifeograph.  If not, see <http://www.gnu.org/licenses/>.
 
 ***********************************************************************************/
 
@@ -33,8 +33,8 @@ EntryParser::reset( Glib::ustring::size_type start, Glib::ustring::size_type end
     m_pos_end = end;
     pos_current = pos_word = pos_alpha = pos_regular = start;
 
-    char_last = CC_NONE;
-    char_req = CC_ANY;
+    m_cc_last = CC_NONE;
+    m_cc_req = CC_ANY;
     word_last.clear();
     alpha_last.clear();
     int_last = 0;
@@ -62,6 +62,7 @@ EntryParser::parse( Glib::ustring::size_type start, Glib::ustring::size_type end
     for( ; pos_current < m_pos_end; ++pos_current )
     {
         char_current = get_char_at( pos_current );
+        m_cc_current = CC_SIGN;
 
         if( m_search_str.size() > 0 )
         {
@@ -89,115 +90,102 @@ EntryParser::parse( Glib::ustring::size_type start, Glib::ustring::size_type end
             case 0:     // should never be the case
             case '\n':
             case '\r':
+                m_cc_current = CC_NEWLINE;
                 process_char( CF_NEWLINE,
                               CF_NUM_CKBX|CF_ALPHA|CF_FORMATCHAR|
                               CF_SLASH|CF_DOTDATE|CF_MORE|CF_TAB|CF_IGNORE,
-                              0, NULL,
-                              CC_NEWLINE );
+                              0, NULL );
                 break;
             case ' ':
+                m_cc_current = CC_SPACE;
                 process_char( CF_SPACE,
                               CF_ALPHA|CF_NUMBER|CF_SLASH|CF_DOTDATE|CF_CHECKBOX,
-                              CF_NOTHING, &EntryParser::trigger_subheading,
-                              CC_SPACE );
+                              CF_NOTHING, &EntryParser::trigger_subheading );
                 break;
-            case '*':
+            case '*': // SIGN
                 process_char( CF_ASTERISK,
                               CF_NUM_CKBX|CF_ALPHA|CF_SLASH|CF_DOTDATE,
-                              CF_NOTHING, &EntryParser::trigger_bold,
-                              CC_SIGN );
+                              CF_NOTHING, &EntryParser::trigger_bold );
                 break;
-            case '_':
+            case '_': // SIGN
                 process_char( CF_UNDERSCORE,
                               CF_NUM_CKBX|CF_SLASH|CF_DOTDATE,
-                              CF_NOTHING, &EntryParser::trigger_italic,
-                              CC_SIGN );
+                              CF_NOTHING, &EntryParser::trigger_italic );
                 break;
-            case '=':
+            case '=': // SIGN
                 process_char( CF_EQUALS,
                               CF_NUM_CKBX|CF_ALPHA|CF_SLASH|CF_DOTDATE,
-                              CF_NOTHING, &EntryParser::trigger_strikethrough,
-                              CC_SIGN );
+                              CF_NOTHING, &EntryParser::trigger_strikethrough );
                 break;
-            case '#':
+            case '#': // SIGN
                 process_char( CF_HASH,
                               CF_NUM_CKBX|CF_ALPHA|CF_SLASH|CF_DOTDATE,
-                              CF_NOTHING, &EntryParser::trigger_highlight,
-                              CC_SIGN );
+                              CF_NOTHING, &EntryParser::trigger_highlight );
                 break;
-            case '[':
+            case '[': // SIGN
                 process_char( CF_SBB,
                               CF_NUM_CKBX|CF_ALPHA|CF_SLASH|CF_DOTDATE,
-                              CF_NOTHING, &EntryParser::trigger_comment,
-                              CC_SIGN );
+                              CF_NOTHING, &EntryParser::trigger_comment );
                 break;
-            case ']':
+            case ']': // SIGN
                 process_char( CF_SBE,
                               CF_NUM_CKBX|CF_ALPHA|CF_SLASH|CF_DOTDATE,
-                              0, NULL,
-                              CC_SIGN );
+                              0, NULL );
                 break;
             case '0': case '1': case '2': case '3': case '4':
             case '5': case '6': case '7': case '8': case '9':
                 handle_number();   // calculates numeric value
+                m_cc_current = CC_NUMBER;
                 process_char( CF_NUMBER,
                               CF_SLASH|CF_ALPHA|CF_DOTDATE|CF_CHECKBOX,
-                              CF_NOTHING, &EntryParser::trigger_link_date,
-                              CC_NUMBER );
+                              CF_NOTHING, &EntryParser::trigger_link_date );
                 break;
-            case '.':
+            case '.': // SIGN
                 process_char( CF_DOTDATE,
                               CF_NUM_CKBX|CF_ALPHA|CF_SLASH,
-                              CF_NOTHING, &EntryParser::trigger_ignore,
-                              CC_SIGN );
+                              CF_NOTHING, &EntryParser::trigger_ignore );
                 break;
-            case '-':
+            case '-': // SIGN - CC_SIGNSPELL does not seem to be necessary
                 process_char( CF_DOTDATE,
                               CF_NUM_CKBX|CF_ALPHA|CF_SLASH,
-                              0, NULL,
-                              CC_SIGN ); // CC_SIGNSPELL does not seem to be necessary
+                              0, NULL );
                 break;
-            case '/':
+            case '/': // SIGN
                 process_char( CF_SLASH|CF_DOTDATE,
                               CF_NUM_CKBX|CF_ALPHA,
-                              0, NULL,
-                              CC_SIGN );
+                              0, NULL );
                 break;
-            case ':':
+            case ':': // SIGN
                 process_char( CF_PUNCTUATION_RAW,
                               CF_NUM_CKBX|CF_ALPHA|CF_SLASH|CF_DOTDATE,
-                              CF_NOTHING, &EntryParser::trigger_link,
-                              CC_SIGN );
+                              CF_NOTHING, &EntryParser::trigger_link );
                 break;
-            case '@':
+            case '@': // SIGN
                 process_char( CF_AT,
                               CF_NUM_CKBX|CF_ALPHA|CF_SLASH|CF_DOTDATE,
-                              CF_NOTHING, &EntryParser::trigger_link_at,
-                              CC_SIGN );
+                              CF_NOTHING, &EntryParser::trigger_link_at );
                 break;
-            case '>':
+            case '>': // SIGN
                 process_char( CF_MORE,
                               CF_NUM_CKBX|CF_ALPHA|CF_SLASH|CF_DOTDATE,
-                              0, NULL,
-                              CC_SIGN );
+                              0, NULL );
                 break;
             case '\t':
+                m_cc_current = CC_TAB;
                 process_char( CF_TAB,
                               CF_NUM_SLSH|CF_ALPHA|CF_DOTDATE,
-                              CF_NOTHING, &EntryParser::trigger_list,
-                              CC_TAB );
+                              CF_NOTHING, &EntryParser::trigger_list );
                 break;
             // LIST CHARS
             case L'☐':
             case L'☑':
-            case L'☒':
+            case L'☒': // SIGN
                 process_char( CF_CHECKBOX,
                               CF_NUM_SLSH|CF_ALPHA|CF_DOTDATE,
-                              0, NULL,
-                              CC_SIGN );
+                              0, NULL );
                 break;
             // MAYBE LATER:
-            /*case '\'':
+            /*case '\'': // SIGN
                 process_char( CF_PUNCTUATION_RAW,
                               CF_ALPHA|CF_NUM_CKBX|CF_DOTDATE|CF_SLASH,
                               0, NULL,
@@ -205,34 +193,41 @@ EntryParser::parse( Glib::ustring::size_type start, Glib::ustring::size_type end
                 break;*/
             default:
                 if( Glib::Unicode::isalpha( char_current ) )
+                {
+                    m_cc_current = CC_ALPHASPELL;
                     process_char( CF_ALPHA,
                                   CF_NUM_CKBX|CF_DOTDATE|CF_SLASH,
-                                  0, NULL,
-                                  CC_ALPHASPELL );
-                else
+                                  0, NULL );
+                }
+                else // SIGN
+                {
                     process_char( CF_PUNCTUATION_RAW,
                                   CF_ALPHA|CF_NUM_CKBX|CF_DOTDATE|CF_SLASH,
-                                  0, NULL,
-                                  CC_SIGN );
+                                  0, NULL );
+                }
                 break;
         }
     }
     // end of the text -treated like new line
     if( m_pos_end > 0 ) // only when finish is not forced
+    {
+        m_cc_current = CC_NEWLINE;
         process_char( CF_NEWLINE|CF_EOT,
                       CF_NUM_CKBX|CF_ALPHA|CF_FORMATCHAR|CF_SLASH|CF_DOTDATE|CF_MORE|CF_TAB,
-                      0, NULL,
-                      CC_NEWLINE );
+                      0, NULL );
+    }
 }
 
 inline void
 EntryParser::process_char( unsigned int satisfies, unsigned int breaks, unsigned int triggers_on,
-                           FPtr_void triggerer, CharClass cc )
+                           FPtr_void triggerer )
 {
+    // NOTE: m_cc_current *must* be set before calling this function
+
     // UPDATE ALPHA LAST
     if( m_flag_handle_word )
     {
-        if( cc & CC_ALPHA ) // CC_SPELLCHECK may be used in the future
+        if( m_cc_current & CC_ALPHA ) // CC_SPELLCHECK may be used in the future
         {
             if( alpha_last.empty() )
                 pos_alpha = pos_current;
@@ -266,7 +261,7 @@ EntryParser::process_char( unsigned int satisfies, unsigned int breaks, unsigned
         {
             if( m_chars_looked_for.front().junction )
                 flag_apply = true;
-            else if( char_last & char_req ) // not junction = final applier
+            else if( m_cc_last & m_cc_req ) // not junction = final applier
             {
                 flag_clear_chars = true;
                 flag_apply = true;
@@ -320,7 +315,7 @@ EntryParser::process_char( unsigned int satisfies, unsigned int breaks, unsigned
         ( this->*applier )();
 
     // UPDATE WORD LAST
-    if( cc & CC_SEPARATOR )
+    if( m_cc_current & CC_SEPARATOR )
         word_last.clear();
     else
     {
@@ -330,7 +325,7 @@ EntryParser::process_char( unsigned int satisfies, unsigned int breaks, unsigned
     }
 
     // UPDATE CHAR CLASS
-    char_last = cc;
+    m_cc_last = m_cc_current;
 }
 
 void
@@ -345,11 +340,11 @@ EntryParser::set_search_str( const Glib::ustring &str )
 void
 EntryParser::trigger_subheading( void )
 {
-    if( char_last == CC_NEWLINE )
+    if( m_cc_last == CC_NEWLINE )
     {
         m_chars_looked_for.clear();
         m_chars_looked_for.push_back( AbsChar( CF_NONSPACE, &EntryParser::apply_subheading_0 ) );
-        char_req = CC_ANY;
+        m_cc_req = CC_ANY;
         m_pos_start = pos_current;
     }
 }
@@ -364,52 +359,52 @@ EntryParser::apply_subheading_0( void )
 void
 EntryParser::trigger_bold( void )
 {
-    if( char_last & CC_NOT_SEPARATOR )
+    if( m_cc_last & CC_NOT_SEPARATOR )
         return;
 
     m_chars_looked_for.clear();
     m_chars_looked_for.push_back( AbsChar( CF_NONSPACE - CF_ASTERISK, NULL ) );
     m_chars_looked_for.push_back( AbsChar( CF_ASTERISK, &EntryParser::apply_bold ) );
-    char_req = CC_NOT_SEPARATOR;
+    m_cc_req = CC_NOT_SEPARATOR;
     m_pos_start = pos_current;
 }
 
 void
 EntryParser::trigger_italic( void )
 {
-    if( char_last & CC_NOT_SEPARATOR )
+    if( m_cc_last & CC_NOT_SEPARATOR )
         return;
 
     m_chars_looked_for.clear();
     m_chars_looked_for.push_back( AbsChar( CF_NONSPACE - CF_UNDERSCORE, NULL ) );
     m_chars_looked_for.push_back( AbsChar( CF_UNDERSCORE, &EntryParser::apply_italic ) );
-    char_req = CC_NOT_SEPARATOR;
+    m_cc_req = CC_NOT_SEPARATOR;
     m_pos_start = pos_current;
 }
 
 void
 EntryParser::trigger_strikethrough( void )
 {
-    if( char_last & CC_NOT_SEPARATOR )
+    if( m_cc_last & CC_NOT_SEPARATOR )
         return;
 
     m_chars_looked_for.clear();
     m_chars_looked_for.push_back( AbsChar( CF_NONSPACE - CF_EQUALS, NULL ) );
     m_chars_looked_for.push_back( AbsChar( CF_EQUALS, &EntryParser::apply_strikethrough ) );
-    char_req = CC_NOT_SEPARATOR;
+    m_cc_req = CC_NOT_SEPARATOR;
     m_pos_start = pos_current;
 }
 
 void
 EntryParser::trigger_highlight( void )
 {
-    if( char_last & CC_NOT_SEPARATOR )
+    if( m_cc_last & CC_NOT_SEPARATOR )
         return;
 
     m_chars_looked_for.clear();
     m_chars_looked_for.push_back( AbsChar( CF_NONSPACE - CF_HASH, NULL ) );
     m_chars_looked_for.push_back( AbsChar( CF_HASH, &EntryParser::apply_highlight ) );
-    char_req = CC_NOT_SEPARATOR;
+    m_cc_req = CC_NOT_SEPARATOR;
     m_pos_start = pos_current;
 }
 
@@ -420,7 +415,7 @@ EntryParser::trigger_comment( void )
     m_chars_looked_for.push_back( AbsChar( CF_SBB|CF_IMMEDIATE, NULL ) );
     m_chars_looked_for.push_back( AbsChar( CF_SBE, NULL ) );
     m_chars_looked_for.push_back( AbsChar( CF_SBE|CF_IMMEDIATE, &EntryParser::apply_comment ) );
-    char_req = CC_ANY;
+    m_cc_req = CC_ANY;
     m_pos_start = pos_current;
 }
 
@@ -432,7 +427,7 @@ EntryParser::trigger_link( void )
     if( m_flag_hidden_link )
         word_last.erase( 0, 1 );
 
-    char_req = CC_ANY;
+    m_cc_req = CC_ANY;
 
     if( word_last == "http" || word_last == "https" ||
         word_last == "ftp" || word_last == "file" || word_last == "rel" )
@@ -492,7 +487,7 @@ void
 EntryParser::trigger_link_at( void )
 {
     PRINT_DEBUG( "word_last [@]: " + word_last );
-    if( char_last & CC_SEPARATOR )
+    if( m_cc_last & CC_SEPARATOR )
         return;
 
     m_flag_hidden_link = false;
@@ -501,14 +496,14 @@ EntryParser::trigger_link_at( void )
     m_chars_looked_for.push_back( AbsChar( CF_ALPHA|CF_NUMBER, NULL ) ); // TODO: add dash
     m_chars_looked_for.push_back( AbsChar( CF_TAB|CF_NEWLINE|CF_SPACE,
                                            &EntryParser::apply_link ) );
-    char_req = CC_ANY;
+    m_cc_req = CC_ANY;
     m_pos_start = pos_word;
 }
 
 void
 EntryParser::trigger_link_date( void )
 {
-    char_req = CC_ANY;
+    m_cc_req = CC_ANY;
     m_chars_looked_for.clear();
     m_chars_looked_for.push_back( AbsChar( CF_NUMBER, NULL ) );
     m_chars_looked_for.push_back( AbsChar( CF_NUMBER, NULL ) );
@@ -539,25 +534,25 @@ EntryParser::trigger_link_date( void )
 void
 EntryParser::trigger_list( void )
 {
-    if( char_last != CC_NEWLINE )
+    if( m_cc_last != CC_NEWLINE )
         return;
 
     m_chars_looked_for.clear();
     m_chars_looked_for.push_back( AbsChar( CF_CHECKBOX, &EntryParser::junction_list, true ) );
-    char_req = CC_ANY;
+    m_cc_req = CC_ANY;
     m_pos_start = pos_current;
 }
 
 void
 EntryParser::trigger_ignore( void )
 {
-    if( char_last == CC_NEWLINE )
+    if( m_cc_last == CC_NEWLINE )
     {
         m_chars_looked_for.clear();
         m_chars_looked_for.push_back( AbsChar( CF_TAB|CF_IMMEDIATE,
                                                &EntryParser::junction_ignore,
                                                true ) ); // junction
-        char_req = CC_ANY;
+        m_cc_req = CC_ANY;
         m_pos_start = pos_current;
     }
 }
@@ -594,7 +589,7 @@ void
 EntryParser::junction_list( void )
 {
     m_chars_looked_for.front().flags = CF_SPACE|CF_IMMEDIATE;
-    char_req = CC_ANY;
+    m_cc_req = CC_ANY;
 
     switch( char_current )
     {
@@ -665,7 +660,7 @@ EntryParser::apply_check_ccl_0( void )
 inline void
 EntryParser::handle_number( void )
 {
-    if( char_last == CC_NUMBER )
+    if( m_cc_last == CC_NUMBER )
     {
         int_last *= 10;
         int_last += ( char_current - '0' );
