@@ -124,8 +124,7 @@ class EntryParser
 
         void                        process_char( unsigned int, unsigned int,
                                                   unsigned int,
-                                                  FPtr_void,
-                                                  CharClass );
+                                                  FPtr_void );
         //void                        process_newline( void );
 
         // TRIGGERERS
@@ -196,8 +195,9 @@ class EntryParser
         Glib::ustring::size_type    pos_tab;        // position of invisible link tab
         Glib::ustring::size_type    pos_search;
 
-        CharClass                   char_last;
-        CharClass                   char_req;       // required previous char
+        CharClass                   m_cc_last;
+        CharClass                   m_cc_current;
+        CharClass                   m_cc_req;       // required previous char
         gunichar                    char_current;
         Glib::ustring               word_last;
         Glib::ustring               alpha_last; // last word consisting purely of letters
