@@ -1,21 +1,21 @@
 /***********************************************************************************
 
-	Copyright (C) 2007-2011 Ahmet Öztürk (aoz_2@yahoo.com)
+    Copyright (C) 2007-2011 Ahmet Öztürk (aoz_2@yahoo.com)
 
-	This file is part of Lifeograph.
+    This file is part of Lifeograph.
 
-	Lifeograph is free software: you can redistribute it and/or modify
-	it under the terms of the GNU General Public License as published by
-	the Free Software Foundation, either version 3 of the License, or
-	(at your option) any later version.
+    Lifeograph is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
 
-	Lifeograph is distributed in the hope that it will be useful,
-	but WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-	GNU General Public License for more details.
+    Lifeograph is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
 
-	You should have received a copy of the GNU General Public License
-	along with Lifeograph.  If not, see <http://www.gnu.org/licenses/>.
+    You should have received a copy of the GNU General Public License
+    along with Lifeograph.  If not, see <http://www.gnu.org/licenses/>.
 
 ***********************************************************************************/
 
@@ -32,37 +32,37 @@
 namespace LIFEO
 {
 
-static const int		BROWSING_HISTORY_SIZE = 5;
+static const int        BROWSING_HISTORY_SIZE = 5;
 
 
 class PanelMain
 {
-	private:
-		typedef DiaryElement* PtrDiaryElement;
+    private:
+        typedef DiaryElement* PtrDiaryElement;
 
-	public:
-								PanelMain( void );
+    public:
+                                PanelMain( void );
 
         bool                    is_cur_elem( DiaryElement *elem )
         { return( elem == get_cur_elem() ); }
 
-		void					show( ElementShowerProto* );
+        void                    show( ElementShowerProto* );
 
         void                    handle_logout( void );
-	
-		void					go_back( void );
-		//void					go_forward( void );
 
-		void					remove_element_from_history( DiaryElement* );
-		void					clear_history( void );
+        void                    go_back( void );
+        //void                  go_forward( void );
 
-		PtrDiaryElement			get_cur_elem( void )
-		{ return( m_browsing_history[ m_bhist_index ] ); }
-		DiaryElement::Type		get_cur_elem_type( void )
-		{
-			return( m_browsing_history[ m_bhist_index ] == NULL ?
-					DiaryElement::ET_NONE : m_browsing_history[ m_bhist_index ]->get_type() );
-		}
+        void                    remove_element_from_history( DiaryElement* );
+        void                    clear_history( void );
+
+        PtrDiaryElement         get_cur_elem( void )
+        { return( m_browsing_history[ m_bhist_index ] ); }
+        DiaryElement::Type      get_cur_elem_type( void )
+        {
+            return( m_browsing_history[ m_bhist_index ] == NULL ?
+                    DiaryElement::ET_NONE : m_browsing_history[ m_bhist_index ]->get_type() );
+        }
 
         void                    set_icon( const Glib::RefPtr< Gdk::Pixbuf > icon )
         {
@@ -91,8 +91,8 @@ class PanelMain
         bool                    handle_title_hover( GdkEventCrossing* );
         bool                    handle_title_hover_out( GdkEventCrossing* );
 
-		PtrDiaryElement			m_browsing_history[ BROWSING_HISTORY_SIZE ];
-		unsigned int			m_bhist_index;	// browsing history index
+        PtrDiaryElement         m_browsing_history[ BROWSING_HISTORY_SIZE ];
+        unsigned int            m_bhist_index;  // browsing history index
 
     protected:
         void                    set_extra_tools( Gtk::Widget* );
