@@ -20,7 +20,8 @@
 ***********************************************************************************/
 
 
-#include "lifeobase.hpp"
+#include "lifeograph.hpp"
+#include "app_window.hpp"
 #include "printing.hpp"
 #include "diary.hpp"
 
@@ -117,7 +118,7 @@ PrintOpr::clear_content( void )
 }
 
 void
-PrintOpr::reset( void )
+PrintOpr::init_variables( const Glib::RefPtr< Gtk::PrintContext > &print_context  )
 {
     m_n_pages = 1;
     m_v_offset = 0.0;
@@ -127,15 +128,17 @@ PrintOpr::reset( void )
     m_chapters = Diary::d->get_current_chapter_ctg();
     m_iter_chapter = m_chapters->rbegin();
 
+    m_parser.m_max_thumbnail_width = ( print_context->get_width() / 2 );
+
     // SETTING ENTRY ITERATORS
     m_iter_entry = Diary::d->get_entries().rbegin();
     if( m_opt_one_entry )
     {
-        if( Lifeobase::panel_main->get_cur_elem_type() != DiaryElement::ET_ENTRY )
+        if( AppWindow::p->panel_main->get_cur_elem_type() != DiaryElement::ET_ENTRY )
             throw LIFEO::Error( "Current element is not an entry. Printing aborted." );
 
         m_iter_entry_end = EntryIterReverse( Diary::d->get_entries().find(
-                Lifeobase::panel_main->get_cur_elem()->get_date().m_date ) );
+                AppWindow::p->panel_main->get_cur_elem()->get_date().m_date ) );
         m_iter_entry = m_iter_entry_end;
         m_iter_entry--;
     }
@@ -189,10 +192,10 @@ PrintOpr::on_create_custom_widget( void )
 
     // could not figure out how to use Gtk::Builder in conjunction with PrintDialog
     // using a dedicated ui file may be one way of doing it
-//    Lifeobase::builder->get_widget( "vbox_printing", s_vbox_extras );
-//    Lifeobase::builder->get_widget( "rbutton_print_entry", m_rbutton_entry );
-//    Lifeobase::builder->get_widget( "rbutton_print_filtered", m_rbutton_filtered );
-//    Lifeobase::builder->get_widget( "rbutton_print_diary", m_rbutton_diary );
+//    Lifeograph::builder->get_widget( "vbox_printing", s_vbox_extras );
+//    Lifeograph::builder->get_widget( "rbutton_print_entry", m_rbutton_entry );
+//    Lifeograph::builder->get_widget( "rbutton_print_filtered", m_rbutton_filtered );
+//    Lifeograph::builder->get_widget( "rbutton_print_diary", m_rbutton_diary );
 
     grid_main->show_all_children();
 
@@ -223,7 +226,7 @@ PrintOpr::on_done( Gtk::PrintOperationResult result )
 
     if( result == Gtk::PRINT_OPERATION_RESULT_ERROR )
     {
-        Gtk::MessageDialog err_dialog( *Lifeobase::base, "Printing failed", false,
+        Gtk::MessageDialog err_dialog( *AppWindow::p, "Printing failed", false,
                 Gtk::MESSAGE_ERROR, Gtk::BUTTONS_OK, true );
         err_dialog.run();
     }
@@ -263,7 +266,7 @@ PrintOpr::show_page_setup( void )
 {
     // Show the page setup dialog, asking it to start with the existing settings:
     Glib::RefPtr< Gtk::PageSetup > new_page_setup =
-            Gtk::run_page_setup_dialog( *Lifeobase::base, m_refPageSetup, m_refSettings );
+            Gtk::run_page_setup_dialog( *AppWindow::p, m_refPageSetup, m_refSettings );
 
     //Save the chosen page setup dialog for use when printing, previewing, or
     //showing the page setup dialog again:
@@ -460,10 +463,10 @@ void
 PrintOpr::on_begin_print( const Glib::RefPtr< Gtk::PrintContext > &print_context )
 {
     clear_content();
-    reset();
+    init_variables( print_context );
 
     // PROCESSING THE MATERIAL TO PRINT
-    bool more;
+    bool more( true );
     do
     {
         switch( get_more() )
@@ -690,14 +693,14 @@ EntryParserPango::apply_link( void )
         if( word_last.find( "rel://" ) == 0 )
             word_last.replace( 0, 5, "file://" + Glib::path_get_dirname( Diary::d->get_path() ) );
 
-        if( word_last.find( "file:///" ) == 0  &&
+        if( word_last.find( "file:///" ) == 0 &&
             // there can be no text on the same line as the image:
-            get_char_at( m_pos_start - 1 ) == '\n' &&
-            ( pos_current == m_pos_end ? true : get_char_at( pos_current ) == '\n' ) )
+            get_char_at( m_pos_start - 1 ) == '\n' && m_cc_current == CC_NEWLINE )
         {
             try
             {
-                m_pango_pixbuf = Lifeobase::get_thumbnail( Glib::filename_from_uri( word_last ) );
+                m_pango_pixbuf =Lifeograph::get_thumbnail( Glib::filename_from_uri( word_last ),
+                                                          m_max_thumbnail_width );
                 m_pango_return = Printable::PT_IMAGE;
                 m_pango_begin = pos_current;
 
