@@ -106,6 +106,7 @@ class EntryParserPango : public EntryParser
 
         bool                    option_use_theme_font;
         bool                    option_hide_comments;
+        int                     m_max_thumbnail_width;
 
     protected:
         void                    apply_regular( void );
@@ -161,7 +162,7 @@ class PrintOpr : public Gtk::PrintOperation
         PrintOpr( void );
         Printable::Type         get_more( void );
         void                    clear_content( void );
-        void                    reset( void );
+        void                    init_variables( const Glib::RefPtr< Gtk::PrintContext >& );
 
         // PrintOperation default signal handler overrides:
         void                    on_status_changed( void );
