@@ -1,21 +1,21 @@
 /***********************************************************************************
 
-	Copyright (C) 2007-2011 Ahmet Öztürk (aoz_2@yahoo.com)
+    Copyright (C) 2007-2011 Ahmet Öztürk (aoz_2@yahoo.com)
 
-	This file is part of Lifeograph.
+    This file is part of Lifeograph.
 
-	Lifeograph is free software: you can redistribute it and/or modify
-	it under the terms of the GNU General Public License as published by
-	the Free Software Foundation, either version 3 of the License, or
-	(at your option) any later version.
+    Lifeograph is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
 
-	Lifeograph is distributed in the hope that it will be useful,
-	but WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-	GNU General Public License for more details.
+    Lifeograph is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
 
-	You should have received a copy of the GNU General Public License
-	along with Lifeograph.  If not, see <http://www.gnu.org/licenses/>.
+    You should have received a copy of the GNU General Public License
+    along with Lifeograph.  If not, see <http://www.gnu.org/licenses/>.
 
 ***********************************************************************************/
 
@@ -24,7 +24,7 @@
 #define LIFEOGRAPH_LISTITEMDIARY_HEADER
 
 
-#include "helpers.hpp"	// i18n headers
+#include "helpers.hpp"  // i18n headers
 #include "entry.hpp"
 #include "diary.hpp"
 #include "views.hpp"
@@ -38,11 +38,11 @@ namespace LIFEO
 class EntryView : public ElementShower< Entry >
 {
     public:
-								EntryView( void );
+                                EntryView( void );
 
-		void					sync( void );
+        void                    sync( void );
 
-		void					focus_tag( void );
+        void                    focus_tag( void );
 
         Glib::ustring           get_title_str( void ) const
         {
@@ -56,19 +56,19 @@ class EntryView : public ElementShower< Entry >
                                                m_ptr2elem->get_date().get_weekday_str() );
         }
         Glib::ustring           get_info_str( void ) const
-        { return Glib::ustring::compose( "Entry last changed on %1",
+        { return Glib::ustring::compose( _( "Entry last changed on %1" ),
                 Date::format_string_do( m_ptr2elem->m_date_changed ) ); }
         Glib::ustring           get_tip_str( void ) const
         {
             return Glib::ustring::compose( "%1: <b>%2</b>\n%3: <b>%4</b>"
-#ifdef LIFEOGRAPH_DEBUG_BUILD
+#if LIFEOGRAPH_DEBUG_BUILD
                     "\nDEID: %5"
 #endif
                     // TRANSLATORS: label of creation date
                     , _( "Created"), m_ptr2elem->get_date_created_str(),
                     // TRANSLATORS: label of last change date
                     _( "Changed"), m_ptr2elem->get_date_changed_str()
-#ifdef LIFEOGRAPH_DEBUG_BUILD
+#if LIFEOGRAPH_DEBUG_BUILD
                     , m_ptr2elem->get_id()
 #endif
                     );
@@ -81,47 +81,50 @@ class EntryView : public ElementShower< Entry >
         bool                    check_title_applicable( const Glib::ustring& ) const;
         bool                    apply_title( const Glib::ustring& );
 
-		void					show( Entry& );
+        void                    show( Entry& );
 
-		void					prepare_for_hiding( Entry& );
+        void                    handle_login( void );
 
-		void					update_formatting_toolbar( void );
-		void					update_highlight_button( void );
+        void                    prepare_for_hiding( Entry& );
+
+        void                    update_formatting_toolbar( void );
+        void                    update_highlight_button( void );
         void                    toggle_comments( void );
+        void                    update_tag_widget( void )
+        { m_widgettaglist->update(); }
+        void                    update_theme( void );
 
         TextbufferDiary*        get_buffer( void ) { return m_textview->m_buffer; }
 
-	protected:
-		enum TagOperation { TO_NONE, TO_ADD, TO_REMOVE, TO_CREATE_AND_ADD };
+    protected:
+        enum TagOperation { TO_NONE, TO_ADD, TO_REMOVE, TO_CREATE_AND_ADD };
 
-		void					remove_selected_tags( void );
         void                    trash_entry( void );
         void                    restore_entry( void );
         void                    dismiss_entry( void );
         void                    print( void );
-		void					toggle_favoredness( void );
-		void					reset_theme( void );
+        void                    toggle_favoredness( void );
+        void                    reset_theme( void );
         void                    hide( void );
         void                    hide_before( void );
         void                    hide_after( void );
-
-		void					handle_login( void );
-		void					handle_textview_changed( void );
-		void					handle_entry_tag_changed( void );
-		void					handle_button_tag_clicked( void );
-		void					handle_treeviewtags_buttonpress( GdkEventButton* );
-		void					handle_drag_data_received(
-										const Glib::RefPtr< Gdk::DragContext >&,
-										int, int,
-										const Gtk::SelectionData&,
-										uint,
-										guint );
+        void                    handle_textview_changed( void );
+        void                    handle_entry_tag_changed( void );
+        void                    handle_button_tag_clicked( void );
+        void                    handle_treeviewtags_buttonpress( GdkEventButton* );
+        void                    handle_drag_data_received(
+                                        const Glib::RefPtr< Gdk::DragContext >&,
+                                        int, int,
+                                        const Gtk::SelectionData&,
+                                        uint,
+                                        guint );
 
         void                    focus_tag_entry( void );
         void                    handle_tag_entry_focus_out( GdkEventFocus* );
         void                    edit_tag_in_entry( const Tag* );
+        void                    remove_selected_tags( void );
 
-		// WIDGETS
+        // WIDGETS
         Gtk::MenuItem           *m_menuitem_toggle_favorite;
         Gtk::SeparatorMenuItem  *m_menuseparator_1, *m_menuseparator_2;
         Gtk::MenuItem           *m_menuitem_reset_theme;
@@ -129,25 +132,25 @@ class EntryView : public ElementShower< Entry >
         Gtk::MenuItem           *m_menuitem_restore;
         Gtk::MenuItem           *m_menuitem_dismiss;
 
-		Gtk::Button				*m_button_bold;
-		Gtk::Button				*m_button_italic;
-		Gtk::Button				*m_button_strikethrough;
-		Gtk::Button				*m_button_highlight;
-		Gtk::Label				*m_label_highlight;
-		Gtk::EventBox			*m_eventbox_highlight;		// necessary to change bg color!!
-		Gtk::Button				*m_button_add_bullet;
-		Gtk::Button				*m_button_add_checkbox;
+        Gtk::Button             *m_button_bold;
+        Gtk::Button             *m_button_italic;
+        Gtk::Button             *m_button_strikethrough;
+        Gtk::Button             *m_button_highlight;
+        Gtk::Label              *m_label_highlight;
+        Gtk::EventBox           *m_eventbox_highlight;      // necessary to change bg color!!
+        Gtk::Button             *m_button_add_bullet;
+        Gtk::Button             *m_button_add_checkbox;
         Gtk::ToggleButton       *m_button_toggle_comments;
 
-		TextviewDiary			*m_textview;
-		Gtk::Box                *m_box_tag_edit;
-		TagWidget				*m_tag_widget;
-		Gtk::Button				*m_button_tag_operation;
+        TextviewDiary           *m_textview;
+        Gtk::Box                *m_box_tag_edit;
+        TagWidget               *m_tag_widget;
+        Gtk::Button             *m_button_tag_operation;
         WidgetTagList           *m_widgettaglist;
         Gtk::Box                *m_hbox_editing_toolbar;
-		TagOperation			m_tag_operation_cur;
+        TagOperation            m_tag_operation_cur;
 
-		Entry                   *m_entry_sync;
+        Entry                   *m_entry_sync;
 
         // ACTIONS
         Glib::RefPtr< Gtk::Action > m_action_bold;
@@ -164,9 +167,9 @@ class EntryView : public ElementShower< Entry >
         Glib::RefPtr< Gtk::Action > m_action_move_line_down;
         Glib::RefPtr< Gtk::Action > m_action_time_stamp;
 
-		bool					m_flag_entrychanged;
+        bool                    m_flag_entrychanged;
 
-	friend class Lifeograph;
+    friend class Lifeograph;
 };
 
 } // end of namespace LIFEO
