@@ -24,7 +24,8 @@
 #include <utime.h>
 
 #include "helpers.hpp"
-#include "lifeobase.hpp"
+#include "lifeograph.hpp"
+#include "app_window.hpp"
 #include "view_login.hpp"
 #include "dialog_password.hpp"
 
@@ -47,40 +48,29 @@ ViewLogin::ViewLogin( void )
     {
         colrec = new Colrec;
 
-        Lifeobase::builder->get_widget( "grid_login", m_grid_login );
-        Lifeobase::builder->get_widget( "treeview_diaries", m_treeview_diaries );
-        Lifeobase::builder->get_widget( "button_new_diary", button_new_diary );
-        Lifeobase::builder->get_widget( "button_open_diary", button_browse_diary );
-        Lifeobase::builder->get_widget( "button_login_edit", m_button_edit_diary );
-        Lifeobase::builder->get_widget( "button_login_read", m_button_read_diary );
-        Lifeobase::builder->get_widget( "button_login_remove_diary", m_button_remove_diary );
+        Lifeograph::builder->get_widget( "grid_login", m_grid_login );
+        Lifeograph::builder->get_widget( "treeview_diaries", m_treeview_diaries );
+        Lifeograph::builder->get_widget( "button_new_diary", button_new_diary );
+        Lifeograph::builder->get_widget( "button_open_diary", button_browse_diary );
+        Lifeograph::builder->get_widget( "button_login_edit", m_button_edit_diary );
+        Lifeograph::builder->get_widget( "button_login_read", m_button_read_diary );
+        Lifeograph::builder->get_widget( "button_login_remove_diary", m_button_remove_diary );
+        Lifeograph::builder->get_widget( "infobar_login", m_infobar );
+        Lifeograph::builder->get_widget( "label_login_infobar", m_label_info );
+        Lifeograph::builder->get_widget( "button_login_infobar", m_button_info );
 
         col_diary = Gtk::manage( new Gtk::TreeView::Column( _( "Name" ), colrec->name ) );
         col_date = Gtk::manage( new Gtk::TreeView::Column( _( STRING::COLHEAD_BY_LAST_SAVE ),
                                                            colrec->date ) );
 
-        m_infobar = Gtk::manage( new Gtk::InfoBar() );
-        m_label_info = Gtk::manage( new Gtk::Label() );
-        m_button_info = Gtk::manage( new Gtk::Button() );
-
         m_treestore_diaries = Gtk::ListStore::create( *colrec );
         m_treesel_diaries = m_treeview_diaries->get_selection();
     }
     catch( ... )
     {
-        throw LIFEO::Error( "creation of login view failed" );
+        throw LIFEO::Error( "Failed to create the login view" );
     }
 
-    // INFOBAR
-    m_label_info->set_line_wrap( true );
-    Gtk::Container *infobar_container(
-            dynamic_cast< Gtk::Container* >( m_infobar->get_content_area() ) );
-    if( infobar_container )
-        infobar_container->add( *m_label_info );
-    m_grid_login->attach( *m_infobar, 0, 0, 1, 1 );
-    m_infobar->add_action_widget( *m_button_info, 0 );
-    m_infobar->show_all_children( true );
-
     // LIST OF DIARIES
     m_treeview_diaries->set_model( m_treestore_diaries );
     col_diary->set_expand( true );
@@ -93,7 +83,7 @@ ViewLogin::ViewLogin( void )
     m_treeview_diaries->drag_dest_set( Gtk::DEST_DEFAULT_ALL, Gdk::ACTION_COPY );
     m_treeview_diaries->drag_dest_add_uri_targets();
 
-    Lifeobase::base->set_default( *m_button_edit_diary );
+    AppWindow::p->set_default( *m_button_edit_diary );
 
     m_button_edit_diary->signal_clicked().connect(
             sigc::mem_fun( this, &ViewLogin::handle_button_edit ) );
@@ -145,7 +135,7 @@ ViewLogin::ViewLogin( void )
                     {
                         std::string path( DIARYDIR "/" );
                         path += file_info->get_name();
-                        Lifeobase::stock_diaries.insert( path );
+                        Lifeograph::stock_diaries.insert( path );
                     }
                     file_info = enumerator->next_file();
                 }
@@ -161,11 +151,11 @@ ViewLogin::ViewLogin( void )
 void
 ViewLogin::handle_start( void )
 {
-    Lifeobase::base->remove();
-    Lifeobase::base->add( *m_grid_login );
-    Lifeobase::base->set_title( PROGRAM_NAME );
-    if( Lifeobase::base->m_flag_open_directly )
-        if( open_selected_diary( Lifeobase::base->m_flag_read_only ) == LIFEO::SUCCESS )
+    AppWindow::p->remove();
+    AppWindow::p->add( *m_grid_login );
+    AppWindow::p->set_title( PROGRAM_NAME );
+    if( Lifeograph::p->m_flag_open_directly )
+        if( open_selected_diary( Lifeograph::p->m_flag_read_only ) == LIFEO::SUCCESS )
             return;
     populate_diaries();
 }
@@ -174,7 +164,7 @@ void
 ViewLogin::handle_logout( void )
 {
     handle_start();
-    if( Lifeobase::loginstatus == Lifeobase::LOGGED_TIME_OUT )
+    if( Lifeograph::loginstatus == Lifeograph::LOGGED_TIME_OUT )
         show_info( Gtk::MESSAGE_INFO, _( STRING::ENTER_PASSWORD_TIMEOUT ) );
     else if( m_flag_info_is_visible )
         hide_infobar();
@@ -188,8 +178,8 @@ ViewLogin::populate_diaries( void )
     struct stat fst;    // file date stat
 
     m_treestore_diaries->clear();
-    for( ListPaths::reverse_iterator iter = Lifeobase::settings.recentfiles.rbegin();
-         iter != Lifeobase::settings.recentfiles.rend();
+    for( ListPaths::reverse_iterator iter = Lifeograph::settings.recentfiles.rbegin();
+         iter != Lifeograph::settings.recentfiles.rend();
          ++iter )
     {
         row = *( m_treestore_diaries->append() );
@@ -204,8 +194,8 @@ ViewLogin::populate_diaries( void )
     }
 
     // STOCK DIARIES
-    for( ListPaths::iterator itr_diary = Lifeobase::stock_diaries.begin();
-         itr_diary != Lifeobase::stock_diaries.end();
+    for( ListPaths::iterator itr_diary = Lifeograph::stock_diaries.begin();
+         itr_diary != Lifeograph::stock_diaries.end();
          ++itr_diary )
     {
         std::string path( *itr_diary );
@@ -218,7 +208,7 @@ ViewLogin::populate_diaries( void )
                 time_t( m_sort_date_type == SDT_SAVE ? fst.st_mtime : fst.st_atime ) );
     }
 
-    if( Lifeobase::settings.recentfiles.size() > 0 )
+    if( m_treestore_diaries->children().size() > 0 )
         m_treesel_diaries->select( m_treestore_diaries->get_iter( "0" ) );
 }
 
@@ -271,7 +261,13 @@ ViewLogin::open_selected_diary( bool read_only )
             show_info( Gtk::MESSAGE_INFO, _( STRING::DIARY_NOT_READABLE ) );
             break;
         case FILE_LOCKED:
-            show_info( Gtk::MESSAGE_INFO, _( STRING::DIARY_LOCKED ) );
+            show_info( Gtk::MESSAGE_INFO,
+                       Glib::ustring::compose( _( STRING::DIARY_LOCKED ),
+                               Glib::ustring::compose( "<a href=\"file://%1\" title=\"%2\">%3</a>",
+                                                       Glib::path_get_dirname( m_path_cur ),
+                                                       _( "Click to open the containing folder" ),
+                                                       m_path_cur + LOCK_SUFFIX ) ) );
+            m_button_edit_diary->set_visible( false );
             break;
         default:
             show_info( Gtk::MESSAGE_ERROR, _( STRING::FAILED_TO_OPEN_DIARY ) );
@@ -322,7 +318,7 @@ ViewLogin::open_selected_diary( bool read_only )
     if( Diary::d->is_old() && read_only == false )
     {
         Gtk::MessageDialog *messagedialog
-                = new Gtk::MessageDialog( *Lifeobase::base,
+                = new Gtk::MessageDialog( *AppWindow::p,
                                           "",
                                           false,
                                           Gtk::MESSAGE_WARNING,
@@ -346,22 +342,9 @@ ViewLogin::open_selected_diary( bool read_only )
     // HANDLE ENCRYPTION
     if( Diary::d->is_encrypted() )
     {
-        static DialogPasswordPrompt *dialog_password = NULL;
-        if( dialog_password == NULL )
-            Lifeobase::builder->get_widget_derived(
-                    "dialog_import_password", dialog_password );
-        dialog_password->set_transient_for( *Lifeobase::base );
-        dialog_password->set_path( Diary::d->get_name() );
-
-        if( RESPONSE_GO == ( m_password_attempt_no == 0 ?
-                dialog_password->run() : dialog_password->run_again() ) )
+        if( DialogPassword::launch( DialogPassword::OT_OPEN, Diary::d, m_password_attempt_no )
+                != RESPONSE_GO )
         {
-            Diary::d->set_passphrase( dialog_password->get_password() );
-            dialog_password->hide();
-        }
-        else
-        {
-            dialog_password->hide();
             Diary::d->clear();
             return LIFEO::ABORTED;
         }
@@ -371,11 +354,11 @@ ViewLogin::open_selected_diary( bool read_only )
     switch( result = Diary::d->read_body() )
     {
         case LIFEO::SUCCESS:
-            Lifeobase::base->login();
+            AppWindow::p->login();
             break;
         case WRONG_PASSWORD:
             Diary::d->clear();
-            sleep( ++m_password_attempt_no ); // wait longer at every failed attempt
+            m_password_attempt_no++;
             return open_selected_diary( read_only );
         case CORRUPT_FILE:
             show_info( Gtk::MESSAGE_ERROR, _( STRING::CORRUPT_DIARY ) );
@@ -392,7 +375,7 @@ void
 ViewLogin::remove_selected_diary( void )
 {
     m_path_removed = m_path_cur;
-    Lifeobase::settings.recentfiles.erase( m_path_removed );
+    Lifeograph::settings.recentfiles.erase( m_path_removed );
     populate_diaries();
     show_info( Gtk::MESSAGE_INFO,
                Glib::ustring::compose( _( "Removed diary: %1" ), m_path_removed ),
@@ -402,7 +385,7 @@ ViewLogin::remove_selected_diary( void )
 void
 ViewLogin::create_new_diary( void )
 {
-    DialogSaveDiary *dialogsavediary = new DialogSaveDiary;
+    /*DialogSaveDiary *dialogsavediary = new DialogSaveDiary;
     dialogsavediary->set_current_folder( Glib::get_home_dir() );
 
     if( dialogsavediary->run() == Gtk::RESPONSE_ACCEPT )
@@ -410,10 +393,19 @@ ViewLogin::create_new_diary( void )
         Diary::d->init_new(
                 dialogsavediary->get_filename_default() );
         delete dialogsavediary;
-        Lifeobase::base->login();
+        Lifeograph::p->login();
     }
     else
-        delete dialogsavediary;
+        delete dialogsavediary;*/
+    std::string path(Glib::get_home_dir() + "/new diary.diary" );
+    std::string pass;
+    if( DialogSaveDiary::launch( path, pass ) == Gtk::RESPONSE_ACCEPT )
+    {
+        Diary::d->init_new( path );
+        if( pass.size() >= LIFEO::PASSPHRASE_MIN_SIZE )
+            Diary::d->set_passphrase( pass );
+        AppWindow::p->login();
+    }
 }
 
 void
@@ -443,7 +435,7 @@ void
 ViewLogin::show_info( Gtk::MessageType type, const Glib::ustring &text,
                       const Glib::ustring &button, InfoResponse response )
 {
-    m_label_info->set_text( text );
+    m_label_info->set_markup( text );
     m_button_info->set_label( button );
     m_resp_cur = response;
     m_infobar->set_message_type( type );
@@ -456,7 +448,7 @@ ViewLogin::handle_infobar_response( int )
 {
     if( m_resp_cur == RESP_UNDO )
     {
-        Lifeobase::settings.recentfiles.insert( m_path_removed );
+        Lifeograph::settings.recentfiles.insert( m_path_removed );
         populate_diaries();
     }
 
@@ -476,7 +468,7 @@ ViewLogin::handle_diary_selection_changed( void )
 {
     m_password_attempt_no = 0;
 
-    if( Lifeobase::m_internaloperation )
+    if( Lifeograph::m_internaloperation )
         return;
 
     bool flag_selection( m_treesel_diaries->count_selected_rows() > 0 );
@@ -486,8 +478,8 @@ ViewLogin::handle_diary_selection_changed( void )
     else
         m_path_cur = "";
 
-    bool flag_not_stock( Lifeobase::stock_diaries.find( m_path_cur ) ==
-            Lifeobase::stock_diaries.end() );
+    bool flag_not_stock( Lifeograph::stock_diaries.find( m_path_cur ) ==
+            Lifeograph::stock_diaries.end() );
     m_button_remove_diary->set_visible( flag_selection && flag_not_stock );
     m_button_edit_diary->set_visible( flag_selection && flag_not_stock );
     m_button_read_diary->set_visible( flag_selection );
@@ -519,8 +511,8 @@ ViewLogin::handle_key_release( GdkEventKey *event )
 void
 ViewLogin::open_activated_diary( void )
 {
-    open_selected_diary( Lifeobase::stock_diaries.find( m_path_cur ) !=
-            Lifeobase::stock_diaries.end() ); // read only if stock diary
+    open_selected_diary( Lifeograph::stock_diaries.find( m_path_cur ) !=
+            Lifeograph::stock_diaries.end() ); // read only if stock diary
 
     m_flag_diary_activated = false;
 }
@@ -561,10 +553,10 @@ ViewLogin::handle_dragged_file( const Glib::RefPtr<Gdk::DragContext>& context,
     if( Glib::file_test( filename, Glib::FILE_TEST_IS_DIR ) )
         return;
 
-    if( Lifeobase::settings.recentfiles.find( filename ) != Lifeobase::settings.recentfiles.end() )
+    if( Lifeograph::settings.recentfiles.find( filename ) != Lifeograph::settings.recentfiles.end() )
         return;
 
-    if( Lifeobase::stock_diaries.find( filename ) != Lifeobase::stock_diaries.end() )
+    if( Lifeograph::stock_diaries.find( filename ) != Lifeograph::stock_diaries.end() )
         return;
 
     Gtk::TreeRow row = *( m_treestore_diaries->append() );
@@ -573,7 +565,7 @@ ViewLogin::handle_dragged_file( const Glib::RefPtr<Gdk::DragContext>& context,
     m_treeview_diaries->get_selection()->select( row );
     m_treeview_diaries->scroll_to_row(  m_treestore_diaries->get_path( row ) );
 
-    Lifeobase::settings.recentfiles.insert( filename );
+    Lifeograph::settings.recentfiles.insert( filename );
 
     PRINT_DEBUG( Glib::ustring::compose( "dropped: %1", filename ) );
 
