@@ -25,12 +25,73 @@
 
 #include "widget_tag_list.hpp"
 #include "helpers.hpp"
-#include "lifeobase.hpp"
+#include "lifeograph.hpp"
 
 
 using namespace LIFEO;
 
 
+// TAG WIDGET ======================================================================================
+TagWidget::TagWidget( BaseObjectType *cobject, const Glib::RefPtr<Gtk::Builder> &b )
+:   EntryClear( cobject, b ), m_completion( Gtk::EntryCompletion::create() )
+{
+    m_completion->set_popup_completion( true );
+    m_completion->set_popup_single_match( true );
+    m_completion->set_match_func(
+            sigc::mem_fun( *this, &TagWidget::compare_text ) );
+
+    m_liststore = Gtk::ListStore::create( *PanelExtra::colrec );
+    m_completion->set_model( m_liststore );
+    m_completion->set_text_column( PanelExtra::colrec->name );
+
+    set_completion( m_completion );
+}
+
+bool
+TagWidget::compare_text( const Glib::ustring &text,
+                         const Gtk::TreeModel::const_iterator &iter )
+{
+    Glib::ustring tagname = iter->get_value( PanelExtra::colrec->name );
+    if( text.size() == 1 )
+        return( Glib::Unicode::tolower( tagname[ 0 ] ) ==
+                Glib::Unicode::tolower( text[ 0 ] ) );
+    else
+        return( tagname.lowercase().find( text.lowercase() ) != std::string::npos );
+}
+
+void
+TagWidget::populate( const Tagset *set )
+{
+    m_liststore->clear();
+
+    Gtk::TreeRow row;
+
+    for( Tagset::const_iterator iter = set->begin();
+         iter != set->end();
+         ++iter )
+    {
+        row = *( m_liststore->append() );
+        row[ PanelExtra::colrec->name ] = ( *iter )->get_name();
+    }
+}
+
+void
+TagWidget::populate( void )
+{
+    m_liststore->clear();
+
+    Gtk::TreeRow row;
+
+    for( PoolTags::const_iterator iter = Diary::d->get_tags()->begin();
+         iter != Diary::d->get_tags()->end();
+         ++iter )
+    {
+        row = *( m_liststore->append() );
+        row[ PanelExtra::colrec->name ] = ( *iter ).second->get_name();
+    }
+}
+
+// TAG LIST WIDGET =================================================================================
 WidgetTagList::WidgetTagList( BaseObjectType *cobject, const Glib::RefPtr< Gtk::Builder >& )
 :   DrawingArea( cobject ), m_ptr2entry( NULL ), m_pos_x( MARGIN ), m_pos_y( MARGIN ),
     m_hovered_tag( NULL ), m_flag_editable( true )
@@ -48,20 +109,21 @@ WidgetTagList::WidgetTagList( BaseObjectType *cobject, const Glib::RefPtr< Gtk::
     delete button;
 
     // TAG ICON
-    //ICON_SIZE = Lifeobase::icons->tag_16->get_width(); // we assume that icon is a square
+    //ICON_SIZE = Lifeograph::icons->tag_16->get_width(); // we assume that icon is a square
     /*Cairo::Format format( image_ptr_->get_has_alpha() ?
             Cairo::FORMAT_ARGB32 : Cairo::FORMAT_RGB24 );*/
    /* m_image_surface = Cairo::ImageSurface::create( Cairo::FORMAT_ARGB32,
                                                    ICON_SIZE, ICON_SIZE );
     m_image_context = Cairo::Context::create( m_image_surface );
-    Gdk::Cairo::set_source_pixbuf( m_image_context, Lifeobase::icons->tag_16, 0.0, 0.0 );
+    Gdk::Cairo::set_source_pixbuf( m_image_context, Lifeograph::icons->tag_16, 0.0, 0.0 );
     m_image_context->paint();*/
 
     m_image_surface_add = Cairo::ImageSurface::create( Cairo::FORMAT_ARGB32, 16, 16 );
     m_image_context = Cairo::Context::create( m_image_surface_add );
     Gdk::Cairo::set_source_pixbuf(
             m_image_context,
-            Gtk::IconTheme::get_default()->load_icon( "gtk-add", 16 ), 0.0, 0.0 );
+            render_icon_pixbuf( Gtk::Stock::ADD, Gtk::ICON_SIZE_MENU ),
+            0.0, 0.0 );
     m_image_context->paint();
 }
 
